==> generic-plugin-3.5.0-sources.jar: com/xebialabs/deployit/plugin/generic/deployed/AbstractDeployedArtifact.java <==
package com.xebialabs.deployit.plugin.generic.deployed;

import static com.google.common.base.Strings.nullToEmpty;

import com.xebialabs.deployit.plugin.api.udm.Deployable;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;

@SuppressWarnings("serial")
@Metadata(description = "Abstract deployed that can target any artifact to a generic container")
public abstract class AbstractDeployedArtifact<D extends Deployable> extends AbstractDeployed<D> {

    @Property(hidden = true, description = "Path to which artifact must be copied to on the generic server.")
    private String targetDirectory;

    @Property(hidden = true, defaultValue = "true", description="Is the target directory shared by others on the generic server. When true, the target directory is not deleted during a destroy operation; only the artifacts copied to it.")
    private boolean targetDirectoryShared;

    @Property(hidden = true, defaultValue = "false", description="Create the target directory on the generic server if it does not exist.")
    private boolean createTargetDirectory;

    @Property(required = false, description = "Name of the artifact on the generic server.")
    private String targetFile;


    protected String resolveTargetFileName() {
        return nullToEmpty(getTargetFile()).trim().isEmpty() ? getDeployable().getName() : getTargetFile();
    }

    public String getTargetDirectory() {
        return resolveExpression(targetDirectory);
    }

    public void setTargetDirectory(String targetDirectory) {
        this.targetDirectory = targetDirectory;
    }

    public boolean isTargetDirectoryShared() {
        return targetDirectoryShared;
    }

    public void setTargetDirectoryShared(boolean targetDirectoryShared) {
        this.targetDirectoryShared = targetDirectoryShared;
    }

    public boolean isCreateTargetDirectory() {
        return createTargetDirectory;
    }

    public void setCreateTargetDirectory(boolean createTargetDirectory) {
        this.createTargetDirectory = createTargetDirectory;
    }

    public String getTargetFile() {
        return resolveExpression(targetFile);
    }

    public void setTargetFile(String targetFile) {
        this.targetFile = targetFile;
    }
}

==> generic-plugin-5.0.1-sources.jar: com/xebialabs/deployit/plugin/generic/deployed/AbstractDeployedArtifact.java <==
package com.xebialabs.deployit.plugin.generic.deployed;

import static com.google.common.base.Strings.nullToEmpty;

import com.xebialabs.deployit.plugin.api.udm.Deployable;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;

@SuppressWarnings("serial")
@Metadata(description = "Abstract deployed that can target any artifact to a generic container")
public abstract class AbstractDeployedArtifact<D extends Deployable> extends AbstractDeployed<D> {

    @Property(hidden = true, description = "Path to which artifact must be copied to on the generic server.")
    private String targetDirectory;

    @Property(hidden = true, defaultValue = "true", description="Is the target directory shared by others on the generic server. When true, the target directory is not deleted during a destroy operation; only the artifacts copied to it.", required = false)
    private boolean targetDirectoryShared;

    @Property(hidden = true, defaultValue = "false", description="Create the target directory on the generic server if it does not exist.", required = false)
    private boolean createTargetDirectory;

    @Property(required = false, description = "Name of the artifact on the generic server.")
    private String targetFile;


    protected String resolveTargetFileName() {
        return nullToEmpty(getTargetFile()).trim().isEmpty() ? getDeployable().getName() : getTargetFile();
    }

    public String getTargetDirectory() {
        return resolveExpression(targetDirectory);
    }

    public void setTargetDirectory(String targetDirectory) {
        this.targetDirectory = targetDirectory;
    }

    public boolean isTargetDirectoryShared() {
        return targetDirectoryShared;
    }

    public void setTargetDirectoryShared(boolean targetDirectoryShared) {
        this.targetDirectoryShared = targetDirectoryShared;
    }

    public boolean isCreateTargetDirectory() {
        return createTargetDirectory;
    }

    public void setCreateTargetDirectory(boolean createTargetDirectory) {
        this.createTargetDirectory = createTargetDirectory;
    }

    public String getTargetFile() {
        return resolveExpression(targetFile);
    }

    public void setTargetFile(String targetFile) {
        this.targetFile = targetFile;
    }
}
